flutter_3d_controller library

Classes

ModelViewerProController
Controller for a ModelViewerProViewer widget.
ModelViewerProViewer
A widget that renders an interactive 3D model (GLB or GLTF format).

Mixins

AnimationOperations
Mixin that adds animation control to ModelViewerProController.
AssetLoaderOperations
Mixin that helps load Flutter assets into the model-viewer WebView.
CameraOperations
Mixin that adds camera control to ModelViewerProController.
EnvironmentOperations
Mixin that adds environment and skybox image control to ModelViewerProController.
LightingOperations
Mixin that adds lighting, shadow, and background control to ModelViewerProController.
MeshOperations
Mixin that adds mesh querying and manipulation to ModelViewerProController.