AnimationOperations mixin
Mixin that adds animation control to ModelViewerProController.
Works with GLB / GLTF files that contain embedded animations. All timing values are in seconds.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webViewController → WebViewController?
-
The
WebViewControllersupplied by the owning controller.no setter
Methods
-
getAnimationDuration(
) → Future< double?> - Returns the total duration of the currently active animation in seconds.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseAnimation(
) → Future< void> - Pauses the currently playing animation at its current position.
-
playAnimation(
) → Future< void> - Starts playing the model's animation(s).
-
setAnimationTime(
double timeInSeconds) → Future< void> -
Seeks to
timeInSecondsin the animation timeline. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited